#
# spec file for package perl-Business-ISBN
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Business-ISBN
Name:           perl-Business-ISBN
Version:        3.12.0
Release:        1.2
# 3.012 -> normalize -> 3.12.0
%define cpan_version 3.012
License:        Artistic-2.0
Summary:        Work with International Standard Book Numbers
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/B/BR/BRIANDFOY/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Business::ISBN::Data) >= 20230322.1.0
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.64
BuildRequires:  perl(Test::More) >= 1
BuildRequires:  perl(version) >= 0.86
Requires:       perl(Business::ISBN::Data) >= 20230322.1.0
Provides:       perl(Business::ISBN) = %{version}
Provides:       perl(Business::ISBN10) = %{version}
Provides:       perl(Business::ISBN13) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
This modules handles International Standard Book Numbers, including ISBN-10
and ISBN-13.

The data come from Business::ISBN::Data, which means you can update the
data separately from the code. Also, you can use Business::ISBN::Data with
whatever _RangeMessage.xml_ you like if you have updated data. See that
module for details.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc bad-isbn13s.txt bad-isbns.txt Changes examples isbn13s.txt isbns.txt SECURITY.md
%license LICENSE

%changelog
* Tue Apr 15 2025 Tina Müller <timueller+perl@suse.de>
- updated to 3.12.0 (3.012)
  see /usr/share/doc/packages/perl-Business-ISBN/Changes
  3.012 2025-04-14T18:53:47Z
  * require a newer version.pm for v5.10.1 tests
* Sat Jan  4 2025 Tina Müller <timueller+perl@suse.de>
- updated to 3.11.0 (3.011)
  see /usr/share/doc/packages/perl-Business-ISBN/Changes
  3.011 2025-01-04T03:01:58Z
  * add SECURITY.md; no code changes
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Sun Feb 11 2024 Tina Müller <timueller+perl@suse.de>
- updated to 3.009
  see /usr/share/doc/packages/perl-Business-ISBN/Changes
  3.009 2024-02-10T21:46:10Z
  * refresh distro, update email addresses, move to BRIANDFOY
* Fri Mar 24 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.008
  see /usr/share/doc/packages/perl-Business-ISBN/Changes
  3.008 2023-03-23T19:56:57Z
  * Fix test for GitHub #24. An ISBN that was invalid is now valid.
* Mon Jan 10 2022 Tina Müller <timueller+perl@suse.de>
- updated to 3.007
  see /usr/share/doc/packages/perl-Business-ISBN/Changes
  3.007 2022-01-09T04:33:56Z
  * no code changes. Fix a link in README.pod.
* Wed Jan 20 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.006
  see /usr/share/doc/packages/perl-Business-ISBN/Changes
  3.006 2021-01-19T14:44:51Z
  * freshen distro, dump Travis CI, add Github Actions
  * New Business::ISBN::Data is on the way too
* Thu Dec 12 2019 <timueller+perl@suse.de>
- updated to 3.005
  see /usr/share/doc/packages/perl-Business-ISBN/Changes
  3.005 2019-12-11T20:27:13Z
  * Peter Williams fixed a big problem with ISBN-13 (GitHub #12)
  * You'll need to update Business::ISBN::Data too because Peter
  adjusted the structure of the underlying data structure.
* Tue Apr 25 2017 coolo@suse.com
- updated to 3.004
  see /usr/share/doc/packages/perl-Business-ISBN/Changes
  3.004 2017-04-24T20:02:52Z
  * Remove Mojo dependencies after splitting out Business::xISBN
  (Michiel Beijen)
  * Remove unneeded code from the checksumming stuff (Mike O'Regan)
  * We now test on Windows through AppVeyor
* Wed Sep 21 2016 coolo@suse.com
- updated to 3.003
  see /usr/share/doc/packages/perl-Business-ISBN/Changes
  3.003 2016-09-19T22:03:24Z
  * Clarify everywhere that I'm using Artistic License 2.0
* Thu Aug 11 2016 coolo@suse.com
- updated to 3.002
  see /usr/share/doc/packages/perl-Business-ISBN/Changes
* Sun Sep 21 2014 lars@linux-schulserver.de
- update to 2.09:
  * Break circular dependency on Test::ISBN
  * Add increment and decrement to create new article numbers
    (Markus Spann)
- require Business::ISBN::Data >= 20140910
- also build require perl(GD) and perl(GD::Barcode::EAN13) for
  Barcode testing
* Sat Jan  4 2014 lars@linux-schulserver.de
- update to 2.07
  + Get rid of MYMETA
* Fri Jun 14 2013 coolo@suse.com
- updated to 2.06
  * Fix test with now-valid group code (RT 78671)
  * Update the URL for the Worldcat stuff so xisbn works.
  * Various distro cleanups.
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Aug 24 2011 chris@computersalat.de
- fix build for CentOS
  * Unknown tag: Recommends:
- cleanup spec
  * header
  * remove Author from desc
  * macros
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sat Sep  4 2010 chris@computersalat.de
- recreated by cpanspec 1.78
- noarch pkg
- fix deps
* Sun Aug 30 2009 lars@linux-schulserver.de
- hardcode perl-libwww-perl requirement
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Sun Jun 28 2009 chris@computersalat.de
- update to 2.05
  - 2.05 - Sun Jan 25 00:00:17 2009
  * Updated for latest data in Business::ISBN::Data
  - 2.04_01 - Mon Oct 27 12:08:03 2008
  * Revert the GD prereq. A lot of testers have borked GD
    installs.
  * Require 5.8. Some of the new stuff isn't playing well with
    5.6
  - 2.04 - Sun Oct 26 18:29:20 2008
  * Fix tests that used 99902 as a bad prefix. That now
    belongs to Gabon.
- added perl-macros
  o autogen filelist with perl_gen_filelist
- spec mods
  o added header
  o fixed deps
* Wed May  7 2008 lrupp@suse.de
- update to 2.03
  * Fixed minor distro problems
  * Explore RT #29292. I don't seem to have the problem with
    hyphens for ISBN-13, but let's see what CPAN Testers has to
    say
  * [BUGFIX] ISBN13 was returing "Bookland" for all groups, but
    it shouldn't do that. Now it returns the same thing you'd
    get from ISBN10 (e.g. "English", "German", ... ).
  * [BUGFIX] RT 29089 - I had the wrong _max_length for ISBN13.
    That 13 is the hint that it should be 13. :)
  * [FEATURE] added exportable function valid_isbn_checksum that
    takes care of all of the object stuff for you and just gives
    you the answer. In previous docs, this was called is_valid_checksum
    even though that conflicted with an object method. It was
    documented but never implemented. Now it's there. :)
  * [BUGFIX] now should pass tests under 5.6.2, after a bit of
    backporting. Upgrade already people! :)
  * Don't import import() from Exporter. There are a lot of people
    (apparently) using very old perls, not just CPAN Testers.
  * fixes RT #28843: an ISBN-13 with a bad prefix shouldn't croak,
    but return an object that explains the error.
  * Official release of Business::ISBN to handle ISBN-13
  * Does not handle 979- numbers yet (need publisher data for that)
  * Does handle 978-numbere, which is the 10 digit ISBN with a
    different "country code", so it uses the same publisher data
  * There are significant API changes to handle the new stuff. It's
    not so bad, but test it before you rip out the old Business::ISBN
    stuff.
  * Completely redone internals to handle ISBN-10 and ISBN-13
  * Some interface changes to Business::ISBN 1.x
  * Removed exportable functions.
* Mon Jul 23 2007 lrupp@suse.de
- initial package 1.84
